@@ -33,12 +33,13 @@
 #include "kz-window.h"
 #include "kz-tab-label.h"
 #include "kz-prefs-win.h"
-#include "kz-link.h"
 #include "kz-links-dialog.h"
 #include "mozilla.h"
 #include "kz-bookmark-editor.h"
+#include "kz-bookmark-edit-win.h"
+#include "kz-bookmark-filter.h"
 #include "kz-location-entry-action.h"
-#include "kz-home-action.h"
+#include "kz-scrap-bookmark-action.h"
 #include "google-action.h"
 #include "kz-mozembed.h"
 #include "kz-actions-download.h"
@@ -46,6 +47,8 @@
 #include "kz-paned.h"
 #include "kz-bookmark-menu.h"
 
+#include <time.h>
+
 static GQuark bookmark_quark = 0;
 
 
@@ -54,15 +57,16 @@ act_save (EggAction *action, KzWindow *kz)
 {
 	GtkWidget *widget = KZ_WINDOW_CURRENT_PAGE(kz);
 	KzMozEmbed *kzembed;
+	const gchar *filename;
 
 	g_return_if_fail(KZ_IS_WINDOW(kz));
 	g_return_if_fail(KZ_IS_MOZ_EMBED(widget));
 	
 	kzembed = KZ_MOZ_EMBED(widget);
 	
-	/* FIXME! we need to call mozilla function. */
-	kz_actions_download_open_save_dialog(kz_moz_embed_get_location(kzembed));
-	/* impl_save(kzembed); */
+	filename = kz_actions_download_open_save_dialog(kz_moz_embed_get_location(kzembed), TRUE);
+	if (filename)
+		kz_moz_embed_save_with_content(kzembed, filename);
 }
 
 
@@ -174,6 +178,46 @@ act_clear_loc_ent (EggAction *action, KzWindow *kz)
 	egg_action_activate(focus_action);
 }
 
+static void
+act_open_file (EggAction *action, KzWindow *kz)
+{
+	GtkFileSelection *file_selector;
+	const gchar *filename = NULL;
+	gchar *uri = NULL;
+	gint result;
+	GtkWidget *widget = KZ_WINDOW_CURRENT_PAGE(kz);
+	KzMozEmbed *kzembed;
+
+	g_return_if_fail(KZ_IS_WINDOW(kz));
+	g_return_if_fail(KZ_IS_MOZ_EMBED(widget));
+	
+	file_selector = GTK_FILE_SELECTION(gtk_file_selection_new ("Open file"));
+
+	result = gtk_dialog_run(GTK_DIALOG(file_selector));
+	
+	switch (result)
+	{
+	 case GTK_RESPONSE_OK:
+		filename = gtk_file_selection_get_filename(file_selector);
+		break;
+	 default:
+		break;
+	}
+	if (filename)
+		uri = g_strdup_printf("file://%s", filename);
+
+	gtk_widget_destroy(GTK_WIDGET(file_selector));
+
+	kzembed = KZ_MOZ_EMBED(widget);
+	
+	if (uri)
+	{
+		kz_moz_embed_load_url(kzembed, uri);
+		g_free(uri);
+	}
+}
+
+
 static void
 act_open_selected_links (EggAction *action, KzWindow *kz)
 {
@@ -186,17 +230,21 @@ act_open_selected_links (EggAction *action, KzWindow *kz)
 
 	for (node = list; node; node = g_list_next(node))
 	{
-		KzLink *link = node->data;
+		KzBookmark *link = node->data;
+		const gchar *uri;
 
 		if (!link) continue;
-		if (!link->url) continue;
-		if (kz_link_filter(link)) continue;
 
-		kz_window_open_new_tab_with_parent(KZ_WINDOW(kz), link->url,
+		uri = kz_bookmark_get_link(link);
+		if (!uri) continue;
+
+		if (kz_bookmark_filter_out(link)) continue;
+
+		kz_window_open_new_tab_with_parent(KZ_WINDOW(kz), uri,
 						   widget);
 	}
 
-	g_list_foreach(list, (GFunc) kz_link_unref, NULL);
+	g_list_foreach(list, (GFunc) g_object_unref, NULL);
 	g_list_free(list);
 }
 
@@ -224,7 +272,7 @@ act_forward (EggAction *action, KzWindow *kz)
 		kz_moz_embed_go_forward(KZ_MOZ_EMBED(widget));
 }
 
-
+#if 0
 static void
 act_show_history_menu (EggAction *action, KzWindow *kz)
 {
@@ -260,7 +308,7 @@ act_show_history_menu (EggAction *action, KzWindow *kz)
 					     0,
 					     activate_time);
 }
-
+#endif
 
 static void
 act_go_up (EggAction *action, KzWindow *kz)
@@ -274,6 +322,33 @@ act_go_up (EggAction *action, KzWindow *kz)
 }
 
 
+static void
+act_search_by_selection (EggAction *action, KzWindow *kz)
+{
+ 	EggAction *entry;
+ 	GtkWidget *widget;
+ 	gchar *desc;
+ 
+ 	g_return_if_fail (KZ_IS_WINDOW((kz)));
+ 
+ 	entry = egg_action_group_get_action(kz->actions, "LocationEntry");
+ 
+ 	widget = KZ_WINDOW_CURRENT_PAGE(kz);
+ 	if (!KZ_IS_MOZ_EMBED(widget)) return;
+ 
+ 	desc = kz_moz_embed_get_selection_string(KZ_MOZ_EMBED(widget));
+ 
+ 	if (!desc)
+ 		return;
+ 
+ 	if (*desc) {
+ 		egg_entry_action_set_text (EGG_ENTRY_ACTION (entry), desc);
+ 		egg_action_activate(entry);
+ 	}
+ 	g_free (desc);
+}
+
+
 static void
 act_go_location (EggAction *action, KzWindow *kz)
 {
@@ -444,10 +519,16 @@ static void
 act_view_source (EggAction *action, KzWindow *kz)
 {
 	GtkWidget *widget = KZ_WINDOW_CURRENT_PAGE(kz);
+	GtkWidget *newtab;
 
-	if (!KZ_IS_MOZ_EMBED(widget)) return;
-	
-	kz_moz_embed_view_source(KZ_MOZ_EMBED(widget));
+	g_return_if_fail(KZ_IS_WINDOW(kz));
+
+	if (KZ_IS_MOZ_EMBED(widget))
+	{
+		newtab = kz_window_open_new_tab(kz, NULL);
+		kz_moz_embed_view_source(KZ_MOZ_EMBED(newtab),
+					 kz_moz_embed_get_location(KZ_MOZ_EMBED(widget)));
+	}
 }
 
 
@@ -515,7 +596,7 @@ act_switch_ui_beginner (EggAction *action, KzWindow *kz)
 	g_return_if_fail(KZ_IS_WINDOW (kz));
 
 	if (!egg_toggle_action_get_active(EGG_TOGGLE_ACTION(action))) return;
-	KZ_CONF_SET("Global", "ui_level", level, STRING);
+	KZ_CONF_SET_STR("Global", "ui_level", level);
 }
 
 
@@ -527,7 +608,7 @@ act_switch_ui_medium (EggAction *action, KzWindow *kz)
 	g_return_if_fail(KZ_IS_WINDOW (kz));
 
 	if (!egg_toggle_action_get_active(EGG_TOGGLE_ACTION(action))) return;
-	KZ_CONF_SET("Global", "ui_level", level, STRING);
+	KZ_CONF_SET_STR("Global", "ui_level", level);
 }
 
 
@@ -539,7 +620,7 @@ act_switch_ui_expert (EggAction *action, KzWindow *kz)
 	g_return_if_fail(KZ_IS_WINDOW (kz));
 
 	if (!egg_toggle_action_get_active(EGG_TOGGLE_ACTION(action))) return;
-	KZ_CONF_SET("Global", "ui_level", level, STRING);
+	KZ_CONF_SET_STR("Global", "ui_level", level);
 }
 
 
@@ -550,7 +631,7 @@ act_switch_ui_custom (EggAction *action, KzWindow *kz)
 
 	g_return_if_fail(KZ_IS_WINDOW (kz));
 
-	KZ_CONF_SET("Global", "ui_level", level, STRING);
+	KZ_CONF_SET_STR("Global", "ui_level", level);
 }
 
 
@@ -682,6 +763,21 @@ act_copy_url (EggAction *action, KzWindow *kz)
 }
 
 
+static void
+act_get_body_text (EggAction *action, KzWindow *kz)
+{
+	GtkWidget *widget = KZ_WINDOW_CURRENT_PAGE(kz);
+
+	g_return_if_fail(KZ_IS_WINDOW(kz));
+
+	if (KZ_IS_MOZ_EMBED(widget))
+	{
+		gchar *text = kz_moz_embed_get_body_text(KZ_MOZ_EMBED(widget));
+		g_free(text);
+	}
+}
+
+
 static void
 act_tab_top (EggAction *action, KzWindow *kz)
 {
@@ -903,7 +999,7 @@ act_remove_bookmark (EggAction *action, KzWindow *kz)
 {
 	KzBookmark *folder, *bookmark;
 
-	g_return_if_fail(KZ_IS_WINDOW (kz));
+	g_return_if_fail(KZ_IS_WINDOW(kz));
 
 	bookmark = kz_actions_get_bookmark_for_action(kz);
 	g_return_if_fail(KZ_IS_BOOKMARK(bookmark));
@@ -920,26 +1016,46 @@ act_remove_bookmark (EggAction *action, KzWindow *kz)
 static void
 act_edit_bookmark (EggAction *action, KzWindow *kz)
 {
-	KzBookmark *folder;
+	KzBookmark *bookmark;
 	GtkWidget *widget;
 
-	folder = kz_actions_get_bookmark_for_action(kz);
-	g_return_if_fail(KZ_IS_BOOKMARK(folder));
+	bookmark = kz_actions_get_bookmark_for_action(kz);
+	g_return_if_fail(KZ_IS_BOOKMARK(bookmark));
 
-	if (kz_bookmark_is_folder(folder))
+	if (kz_bookmark_is_folder(bookmark))
 	{
-		widget = kz_bookmark_editor_new(folder);
-		gtk_window_set_transient_for (GTK_WINDOW(widget), GTK_WINDOW(kz));
+		widget = kz_bookmark_editor_new(bookmark);
+		gtk_window_set_transient_for(GTK_WINDOW(widget), GTK_WINDOW(kz));
 		gtk_widget_show (widget);
 		gdk_window_raise(widget->window);
 	}
 	else
 	{
-		g_warning("Implement me!");
+		widget = kz_bookmark_edit_win_new(bookmark);
+		gtk_widget_show(widget);
 	}
 }
 
 
+static void
+act_edit_bookmark_bars (EggAction *action, KzWindow *kz)
+{
+	KzBookmark *bookmark;
+	GtkWidget *widget;
+
+	g_return_if_fail(KZ_IS_WINDOW(kz));
+
+	bookmark = kz_bookmarks->bookmark_bars;
+	g_return_if_fail(KZ_IS_BOOKMARK(bookmark));
+	g_return_if_fail(kz_bookmark_is_folder(bookmark));
+
+	widget = kz_bookmark_editor_new(bookmark);
+	gtk_window_set_transient_for(GTK_WINDOW(widget), GTK_WINDOW(kz));
+	gtk_widget_show (widget);
+	gdk_window_raise(widget->window);
+}
+
+
 static void
 act_update_bookmark (EggAction *action, KzWindow *kz)
 {
@@ -953,6 +1069,55 @@ act_update_bookmark (EggAction *action, KzWindow *kz)
 }
 
 
+static void
+act_add_scrap_bookmark (EggAction *action, KzWindow *kz)
+{
+	KzBookmark *scrap = kz_bookmarks->scrap, *child;
+	GtkWidget *embed;
+	const gchar *title, *uri;
+	gchar *desc = NULL;
+	GTimeVal now;
+	struct tm *date = NULL;
+	time_t t;
+	gchar link_string[20];
+	gchar *link;
+
+	if (!KZ_IS_WINDOW(kz)) return;
+
+	embed = KZ_WINDOW_CURRENT_PAGE(kz);
+	if (!KZ_IS_MOZ_EMBED(embed)) return;
+
+	g_get_current_time(&now);
+
+	title = kz_window_get_title(kz);
+	uri   = kz_window_get_uri(kz);
+	desc  = kz_moz_embed_get_selection_source(KZ_MOZ_EMBED(embed));
+
+	child = kz_bookmark_new_with_attrs(title, uri, desc);
+	kz_bookmark_set_location(child, uri);
+
+	kz_bookmark_set_last_modified(child, now.tv_sec);
+	
+	t = (time_t)now.tv_sec;
+	date = localtime(&t);
+
+	/* link */
+	strftime(link_string, 20, "#%Y%m%d%H%M%S", date);
+	link = g_strdup_printf("file://%s%s",
+			       kz_bookmark_get_location(scrap),
+			       link_string);
+	kz_bookmark_set_link(child, link);
+
+
+	kz_bookmark_prepend(scrap, child);
+	g_object_unref(child);
+
+	if (desc)
+		g_free(desc);
+	/* save scrap.html */
+	kz_bookmark_save(scrap);
+}
+
 static void
 act_extract_links (EggAction *action, KzWindow *kz)
 {
@@ -1075,8 +1240,8 @@ act_restore_session (EggAction *action, KzWindow *kz)
 	current_session = get_current_session_name();
 
 	/* open saved URIs */
-	i = 0;
 	list = kz_profile_enum_key(kz_session, current_session);
+	
 	for (node = list; node; node = g_list_next(node))
 	{
 		const gchar *key = node->data;
@@ -1085,18 +1250,8 @@ act_restore_session (EggAction *action, KzWindow *kz)
 		if (!key_seems_sequential(key, "tab")) continue;
 
 		uri = kz_profile_get_string(kz_session, current_session, key);
-		kz_window_open_new_tab_at_position(kz, uri, i);
+		kz_window_open_new_tab_at_tail(kz, uri);
 		g_free(uri);
-		/*
-		 * gtk_notebook_append_page() always emits 
-		 * "switch-page" signal with page num which is 0 value, so
-		 * we should call gtk_notebook_set_current_page with correct page number.
- 		 */
-		/*
-		 * 2004-02-01: This isn't necessary any more because tab position sets.
-		 */ 
-		gtk_notebook_set_current_page(GTK_NOTEBOOK(kz->notebook), i);
-		i++;
 	}
 	i = 0;
 	/* set locked tab */
@@ -1193,6 +1348,32 @@ act_paned_bottom (EggAction *action, KzWindow *kz)
 }
 
 
+static void
+act_print (EggAction *action, KzWindow *kz)
+{
+	GtkWidget *widget;
+
+	g_return_if_fail(KZ_IS_WINDOW (kz));
+
+	widget = KZ_WINDOW_CURRENT_PAGE(kz);
+	if (!KZ_IS_MOZ_EMBED(widget)) return;
+
+	kz_moz_embed_print(KZ_MOZ_EMBED(widget));
+}
+
+static void
+act_print_preview (EggAction *action, KzWindow *kz)
+{
+	GtkWidget *widget;
+
+	g_return_if_fail(KZ_IS_WINDOW (kz));
+
+	widget = KZ_WINDOW_CURRENT_PAGE(kz);
+	if (!KZ_IS_MOZ_EMBED(widget)) return;
+
+	kz_moz_embed_print_preview(KZ_MOZ_EMBED(widget));
+}
+
 #define CTRL "<control>"
 #define SHFT "<shift>"
 #define SFCT "<shift><control>"
@@ -1220,6 +1401,9 @@ EggActionGroupEntry kz_actions[] =
 
   {"FocusLocationEntry",        N_("Move keyboard focus to location entry"),  NULL, NULL, NULL, G_CALLBACK(act_focus_loc_ent),      NULL},
   {"ClearLocationEntry",        N_("Clear location entry and move keyboard focus to location entry"),  NULL, NULL, NULL, G_CALLBACK(act_clear_loc_ent),      NULL},
+  {"SearchBySelection", N_("Start querying by current selection string "), NULL, NULL, NULL, G_CALLBACK(act_search_by_selection), NULL},
+
+  {"Open",          N_("_Open File"), GTK_STOCK_OPEN, CTRL"O",  NULL, G_CALLBACK(act_open_file), NULL},
 
   {"OpenSelectedLinks", N_("Open selected links"), GTK_STOCK_OPEN, CTRL"G",  NULL, G_CALLBACK(act_open_selected_links), NULL},
 
@@ -1228,6 +1412,9 @@ EggActionGroupEntry kz_actions[] =
 
   {"SavePage",      N_("Save A_s"),     GTK_STOCK_SAVE_AS,      CTRL"S",  NULL, G_CALLBACK(act_save),    NULL},
 	
+  {"PrintPreview",  N_("Print Preview"),GTK_STOCK_PRINT_PREVIEW,NULL,     NULL, G_CALLBACK(act_print_preview),    NULL},
+  {"Print",         N_("_Print"),       GTK_STOCK_PRINT,        CTRL"P",  NULL, G_CALLBACK(act_print),    NULL},
+
   {"Cut",           N_("C_ut"),        GTK_STOCK_CUT,  CTRL"X", NULL, G_CALLBACK(act_cut),        NULL},
   {"Copy",          N_("_Copy"),       GTK_STOCK_COPY, CTRL"C", NULL, G_CALLBACK(act_copy),       NULL},
   {"Paste",         N_("_Paste"),      GTK_STOCK_PASTE,CTRL"V", NULL, G_CALLBACK(act_paste),      NULL},
@@ -1256,6 +1443,8 @@ EggActionGroupEntry kz_actions[] =
 
   {"ViewPageSource", N_("ViewPageSource"), NULL, NULL, NULL, G_CALLBACK(act_view_source), NULL},
 
+  {"GetBodyText", N_("Get Body Text"), NULL, NULL, NULL, G_CALLBACK(act_get_body_text), NULL},
+
   {"ShowHideSidebar", N_("Sidebar"), NULL, NULL, NULL, G_CALLBACK(act_show_hide_sidebar), NULL, TOGGLE_ACTION},
   {"SidebarPosTop",   N_("Sidebar _Top"),    NULL, NULL, NULL, G_CALLBACK(act_paned_top),    NULL, RADIO_ACTION, NULL},
   {"SidebarPosBottom",N_("Sidebar _Bottom"), NULL, NULL, NULL, G_CALLBACK(act_paned_bottom), NULL, RADIO_ACTION, "SidebarPosTop"},
@@ -1292,8 +1481,11 @@ EggActionGroupEntry kz_actions[] =
   {"AddBookmark",               N_("_Add bookmark"),                   NULL, NULL,  NULL, G_CALLBACK(act_add_bookmark),        NULL},
   {"RemoveBookmark",            N_("_Remove the bookmark"),            NULL, NULL,  NULL, G_CALLBACK(act_remove_bookmark),     NULL},
   {"EditBookmarks",             N_("_Edit bookmarks"),                 NULL, NULL,  NULL, G_CALLBACK(act_edit_bookmark),       NULL},
+  {"EditBookmarkBars",          N_("Edit bookmark _bars"),             NULL, NULL,  NULL, G_CALLBACK(act_edit_bookmark_bars),  NULL},
   {"UpdateBookmarkFolder",      N_("_Update bookmark folder"),         NULL, NULL,  NULL, G_CALLBACK(act_update_bookmark),     NULL},
 
+  {"AddScrapBookmark",          N_("_Add scrap bookmark"),             NULL, NULL,  NULL, G_CALLBACK(act_add_scrap_bookmark),        NULL},
+
   {"ExtractLinks", N_("_Extract links"), NULL, NULL,  NULL, G_CALLBACK(act_extract_links), NULL},
   {"ExtractSelectedLinks", N_("E_xtract selected links"), NULL, NULL,  NULL, G_CALLBACK(act_extract_selected_links), NULL},
 
@@ -1310,22 +1502,26 @@ const gint kz_actions_len = G_N_ELEMENTS(kz_actions);
 static void
 set_popup_menu_sensitive (KzWindow *kz, KzBookmark *bookmark)
 {
-	KzBookmark *parent;
+	KzBookmark *bookmark_file;
 	EggAction *action;
-	gboolean has_link, is_folder, has_children;
-	gboolean is_editable, parent_is_editable, is_file;
+	gboolean has_link, is_folder, is_file, has_children;
+	gboolean children_is_editable, is_editable;
 
 	g_return_if_fail(kz && bookmark);
 
-	parent = kz_bookmark_get_parent(bookmark);
+	bookmark_file = kz_bookmark_get_parent_file(bookmark);
 
 	has_link = kz_bookmark_get_link(bookmark) ? TRUE : FALSE;
 	is_folder = kz_bookmark_is_folder(bookmark);
+	is_file = kz_bookmark_is_file(bookmark);
 	has_children = kz_bookmark_has_children(bookmark);
 	is_editable = kz_bookmark_is_editable(bookmark);
-	parent_is_editable = parent && kz_bookmark_is_editable(parent)
-			   ? TRUE : FALSE;
-	is_file = kz_bookmark_is_file(bookmark);
+	if (is_file)
+		children_is_editable = kz_bookmark_file_is_editable(bookmark);
+	else if (is_folder && is_editable)
+		children_is_editable = TRUE;
+	else
+		children_is_editable = FALSE;
 
 	action = egg_action_group_get_action(kz->actions,
 					     "OpenBookmarkInNewTab");
@@ -1337,16 +1533,17 @@ set_popup_menu_sensitive (KzWindow *kz, KzBookmark *bookmark)
 
 	action = egg_action_group_get_action(kz->actions,
 					     "AddBookmark");
-	egg_action_set_sensitive(action, (is_folder && is_editable) ||
-					 (parent_is_editable));
+	egg_action_set_sensitive(action, ((is_file && children_is_editable) ||
+					  (!is_file && is_editable)));
 
 	action = egg_action_group_get_action(kz->actions,
 					     "RemoveBookmark");
-	egg_action_set_sensitive(action, parent_is_editable);
+	egg_action_set_sensitive(action, is_editable);
 
 	action = egg_action_group_get_action(kz->actions,
 					     "EditBookmarks");
-	egg_action_set_sensitive(action, is_editable);
+	egg_action_set_sensitive(action, ((!is_folder && is_editable) ||
+					  children_is_editable));
 
 	action = egg_action_group_get_action(kz->actions,
 					     "UpdateBookmarkFolder");
@@ -1438,6 +1635,8 @@ kz_actions_set_selection_sensitive (KzWindow *kz, KzMozEmbed *kzembed)
 	KZ_WINDOW_SET_SENSITIVE(kz, "Cut",   can_cut);
 	KZ_WINDOW_SET_SENSITIVE(kz, "Copy",  can_copy);
 	KZ_WINDOW_SET_SENSITIVE(kz, "Paste", can_paste);	
+
+	KZ_WINDOW_SET_SENSITIVE(kz, "AddScrapBookmark", can_copy);
 }
 
 
@@ -1643,7 +1842,7 @@ kz_actions_set_sensitive (KzWindow *kz, KzMozEmbed *kzembed)
 	active = egg_toggle_action_get_active(EGG_TOGGLE_ACTION(action));
 	KZ_WINDOW_SET_VISIBLE(kz, "StockSidebarPosMenu", active);
 
-	set_popup_menu_sensitive(kz, kz_bookmark);
+	set_popup_menu_sensitive(kz, kz_bookmarks->menu);
 }
 
 
@@ -1700,14 +1899,16 @@ kz_actions_create_group (KzWindow *kz, GtkAccelGroup *accel_group)
 		g_object_unref(action);
 	}
 
-	/* Home Action */
+
+	/* Scrap Bookmark Action */
 	{
-		action = EGG_ACTION(kz_home_action_new(kz_home, kz));
+		action = EGG_ACTION(kz_scrap_bookmark_action_new(kz_bookmarks->scrap, kz));
 		egg_action_group_add_action(action_group, action);
 		add_accel_entry(action, accel_group, "<alt>Home");
 		g_object_unref(action);
 	}
 
+
 	/* Google Action */
 	{
 		action = EGG_ACTION(google_action_new(kz));
@@ -1748,7 +1949,7 @@ kz_actions_get_bookmark_for_action (KzWindow *kz)
 	if (KZ_IS_BOOKMARK(bookmark))
 		return bookmark;
 
-	return kz_bookmark;
+	return kz_bookmarks->menu;
 }
 
 
@@ -1799,6 +2000,6 @@ kz_actions_popup_bookmark_menu_modal (KzWindow *kz, KzBookmark *bookmark,
 
 	kz_actions_set_bookmark_for_action (kz, NULL);
 
-	set_popup_menu_sensitive (kz, kz_bookmark);
+	set_popup_menu_sensitive (kz, kz_bookmarks->menu);
 }
 
