@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-actions-bookmark.c,v 1.17 2004/03/20 11:49:50 makeinu Exp $
+ *  $Id: kz-actions-bookmark.c,v 1.19 2004/05/05 02:25:57 ikezoe Exp $
  */
 
 #include "kz-actions-bookmark.h"
@@ -273,9 +273,9 @@ EggActionGroupEntry kz_actions_bookmark[] =
   {"CloseWindow",          N_("_Close Window"),           GTK_STOCK_CLOSE,    "<control>W",  NULL, G_CALLBACK(act_close_window), NULL},
 
   {"EditBookmarkItem",     N_("_Edit selected item"),     NULL,               NULL,         NULL, G_CALLBACK(act_edit_bookmark),    NULL},
-  {"InsertBookmark",       N_("Insert _bookmark"),        GTK_STOCK_NEW,      "<control>B", NULL, G_CALLBACK(act_insert_bookmark),  NULL},
+  {"InsertBookmark",       N_("Insert _bookmark"),        KZ_STOCK_BOOKMARK,      "<control>B", NULL, G_CALLBACK(act_insert_bookmark),  NULL},
   {"InsertFolder",         N_("Insert _folder"),          KZ_STOCK_FOLDER,    "<control>F", NULL, G_CALLBACK(act_insert_folder),    NULL},
-  {"InsertRemoteBookmark", N_("Insert _remote bookmark"), GTK_STOCK_SAVE,     "<control>R", NULL, G_CALLBACK(act_insert_remote_bookmark), NULL},
+  {"InsertRemoteBookmark", N_("Insert _remote bookmark"), KZ_STOCK_REMOTE_BOOKMARK,     "<control>R", NULL, G_CALLBACK(act_insert_remote_bookmark), NULL},
   {"InsertSeparator",      N_("Insert _separator"),       KZ_STOCK_SEPARATOR, "<control>P", NULL, G_CALLBACK(act_insert_separator), NULL},
   {"RemoveBookmarkItem",   N_("_Remove selected item"),   GTK_STOCK_DELETE,   "Delete",     NULL, G_CALLBACK(act_remove_selected_item), NULL},
 
