@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark.c,v 1.35 2004/04/12 15:07:45 ikezoe Exp $
+ *  $Id: kz-bookmark.c,v 1.36 2004/05/19 05:17:02 ikezoe Exp $
  */
 
 #include "kz-bookmark.h"
@@ -97,6 +97,8 @@ static void kz_bookmark_set_state         (KzBookmark *bookmark,
 static void kz_bookmark_set_editable      (KzBookmark *bookmark,
 					   gboolean    editable);
 
+static gboolean kz_bookmark_is_loading_all_children (KzBookmark *bookmark);
+
 static void cb_io_load_complete           (KzIO *io,
 					   GError *error,
 					   KzBookmark   *bookmark);
@@ -1227,7 +1229,6 @@ kz_bookmark_regist_sort_func (const gchar *type, GCompareFunc *func)
 gboolean
 kz_bookmark_load_start (KzBookmark *bookmark)
 {
-	KzBookmarkState state;
 	KzIO *io;
 	const gchar *uri;
 
@@ -1236,8 +1237,8 @@ kz_bookmark_load_start (KzBookmark *bookmark)
 	uri = kz_bookmark_get_location(KZ_BOOKMARK(bookmark));
 	if (!uri) return FALSE;
 
-	state = kz_bookmark_get_state(bookmark);
-	if (state == KZ_BOOKMARK_STATE_LOADING)
+	/* check loading state */
+	if (kz_bookmark_is_loading_all_children(bookmark))
 		return TRUE;
 	kz_bookmark_set_state(bookmark, KZ_BOOKMARK_STATE_LOADING);
 
@@ -1439,3 +1440,36 @@ kz_bookmark_get_state (KzBookmark *bookmark)
 	return GPOINTER_TO_INT(g_object_get_qdata(G_OBJECT(bookmark),
 						  state_quark));
 }
+
+
+static gboolean
+kz_bookmark_is_loading_all_children (KzBookmark *bookmark)
+{
+	gboolean ret = FALSE;
+	KzBookmarkState state;
+	GList *children, *node, *next;
+	g_return_val_if_fail(KZ_IS_BOOKMARK(bookmark), FALSE);
+	
+	/* check loading state */
+	children = g_object_get_qdata(G_OBJECT(bookmark), children_quark);
+
+	node = children;
+	while (node)
+	{
+		KzBookmark *child = node->data;
+		if (kz_bookmark_has_children(child))
+		{
+			ret = kz_bookmark_is_loading_all_children(child);
+			if (ret) break;
+		}
+		next = g_list_next(node);
+		state = kz_bookmark_get_state(child);
+		ret = (state == KZ_BOOKMARK_STATE_LOADING) ? TRUE : FALSE;
+		if (ret) break;
+		node = next;
+	}
+
+	return ret;
+}
+
+
