@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmarks-view.c,v 1.7 2004/04/13 11:47:00 ikezoe Exp $
+ *  $Id: kz-bookmarks-view.c,v 1.9 2004/05/05 02:25:57 ikezoe Exp $
  */
 
 #include "kz-bookmarks-view.h"
@@ -527,7 +527,7 @@ insert_bookmark(KzBookmarksView *view,
 		const gchar *icon;
 
 		icon = kz_bookmark_is_file(bookmark)
-			? GTK_STOCK_SAVE : KZ_STOCK_FOLDER;
+			? KZ_STOCK_REMOTE_BOOKMARK : KZ_STOCK_FOLDER;
 		image = gtk_image_new_from_stock(icon,
 						 GTK_ICON_SIZE_MENU);
 		favicon = gtk_widget_render_icon(image, icon,
@@ -549,9 +549,9 @@ insert_bookmark(KzBookmarksView *view,
 		if (!favicon)
 		{
 			GtkWidget *image;
-			image = gtk_image_new_from_stock(GTK_STOCK_NEW,
+			image = gtk_image_new_from_stock(KZ_STOCK_BOOKMARK,
 							 GTK_ICON_SIZE_MENU);
-			favicon = gtk_widget_render_icon(image, GTK_STOCK_NEW,
+			favicon = gtk_widget_render_icon(image, KZ_STOCK_BOOKMARK,
 							 GTK_ICON_SIZE_MENU,
 							 NULL);
 			gtk_widget_destroy(image);
