@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-xbel.c,v 1.38 2004/04/12 15:07:45 ikezoe Exp $
+ *  $Id: kz-xbel.c,v 1.39 2004/05/15 13:27:30 ikezoe Exp $
  */
 
 #include "kazehakase.h"
@@ -468,7 +468,7 @@ parse_child_node (KzBookmark *bookmark, KzXMLNode *parent)
 		}
 		else if (kz_xml_node_name_is(node, "folder"))
 		{
-			KzBookmark *folder = kz_bookmark_pure_folder_new();
+			KzBookmark *folder;
 			const gchar *folded_str;
 			gboolean folded;
 
@@ -497,12 +497,14 @@ parse_child_node (KzBookmark *bookmark, KzXMLNode *parent)
 			parse_child_node(folder, node);
 			BOOKMARK_UNSET_BUILDING(folder);
 
+			/* Does this need? */
+			/*
 			if (kz_bookmark_is_file(folder))
 			{
 				kz_bookmark_remove_all(folder);
 				kz_bookmark_load_start(folder);
 			}
-
+			 */ 
 			g_object_unref(folder);
 		}
 		else if (kz_xml_node_name_is(node, "bookmark"))
