@@ -29,7 +29,9 @@
 #include <glib.h>
 #include "kz-profile.h"
 #include "bookmarks/kz-root-bookmark.h"
-
+#if 0
+#include "migemo.h"
+#endif
 G_BEGIN_DECLS
 
 #define KAZEHAKASE_URI "http://kazehakase.sourceforge.jp/"
@@ -55,8 +57,9 @@ extern KzProfile      *kz_global_profile;
 extern KzProfile      *kz_session;
 extern KzProfile      *kz_proxy;
 extern KzRootBookmark *kz_bookmarks;
-
-
+#if 0
+extern Migemo         *migemo;
+#endif
 #define KZ_CONF_GET(s, k, v, t)					\
 	kz_profile_get_value(kz_global_profile,			\
 			     s, k, &(v), sizeof(v),		\
