@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 
 /*
- *  Copyright (C) 2003 Hiroyuki Ikezoe
+ *  Copyright (C) 2003-2004 Hiroyuki Ikezoe
  *  Copyright (C) 2003 Takuro Ashie
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark-menu.c,v 1.26 2004/03/20 15:30:37 tyuyu Exp $
+ *  $Id: kz-bookmark-menu.c,v 1.30 2004/05/08 14:45:03 ikezoe Exp $
  */
 
 #include "kz-bookmark-menu.h"
@@ -120,10 +120,14 @@ kz_bookmark_menu_create_menuitem (KzBookmark *bookmark, KzWindow *kz,
 	/* submenu */
 	if (kz_bookmark_is_folder(bookmark) && !is_folder_proxy)
 	{
-		GtkWidget *submenu;
+		GtkWidget *submenu, *image;
 
 		submenu = kz_bookmark_menu_create_submenu(bookmark, kz);
 		gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_item), submenu);
+		image = gtk_image_new_from_stock(KZ_STOCK_FOLDER,
+						 KZ_ICON_SIZE_BOOKMARK_MENU);
+		gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(menu_item),
+					      image);
 	}
 	
 	/* favicon */
@@ -210,8 +214,8 @@ kz_bookmark_menu_append_menuitems (GtkMenuShell *shell,KzWindow *kz,
 					KZ_BOOKMARK_MENU_BOOKMARK_KEY);
 	if (prev_folder)
 	{
-		disconnect_folder_signals(folder, shell);
-		disconnect_menu_signals(folder, shell);
+		disconnect_folder_signals(prev_folder, shell);
+		disconnect_menu_signals(prev_folder, shell);
 	}
 
 	children = kz_bookmark_get_children(folder);
@@ -311,7 +315,27 @@ bookmark_folder_open_all (KzBookmark *bookmark, KzWindow *kz)
 	KzBookmark *item = NULL;
 	GtkWidget *parent = NULL;
 	const gchar *channel_uri;
+	gboolean confirm;
 
+	/* confirmation */
+	KZ_CONF_GET("Global", "confirm_open_bookmarks", confirm, BOOL);
+	if (confirm)
+	{
+		GtkWidget *dialog;
+		gint res;
+		dialog = gtk_message_dialog_new(GTK_WINDOW(kz),
+						GTK_DIALOG_DESTROY_WITH_PARENT,
+						GTK_MESSAGE_QUESTION,
+						GTK_BUTTONS_YES_NO,
+						_("Open all bookmarks in this bookmark folder ?"));
+		gtk_dialog_set_default_response(GTK_DIALOG(dialog),
+						GTK_RESPONSE_YES);
+		res = gtk_dialog_run(GTK_DIALOG(dialog));
+		gtk_widget_destroy(dialog);
+	
+		if (res == GTK_RESPONSE_NO) return;
+	}
+	
 	channel_uri = kz_bookmark_get_link(bookmark);
 	if (channel_uri)
 		parent = kz_window_open_new_tab(kz, channel_uri);
