@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-icons.h,v 1.8 2004/03/24 14:45:52 ikezoe Exp $
+ *  $Id: kz-icons.h,v 1.11 2004/05/12 14:43:55 ikezoe Exp $
  */
 
 #ifndef KZ_ICONS_H
@@ -27,15 +27,18 @@
 
 G_BEGIN_DECLS
 
-#define KZ_STOCK_GOOGLE       "kz-google"
-#define KZ_STOCK_GREEN        "kz-green"
-#define KZ_STOCK_RED          "kz-red"
-#define KZ_STOCK_GRAY         "kz-gray"
-#define KZ_STOCK_FOLDER       "kz-folder"
-#define KZ_STOCK_FOLDER_OPEN  "kz-folder-open"
-#define KZ_STOCK_SEPARATOR    "kz-separator"
-#define KZ_STOCK_ANCHOR       "kz-anchor"
-#define KZ_STOCK_BOOKMARK     "kz-bookmark"
+#define KZ_STOCK_GOOGLE          "kz-google"
+#define KZ_STOCK_GREEN           "kz-green"
+#define KZ_STOCK_RED             "kz-red"
+#define KZ_STOCK_GRAY            "kz-gray"
+#define KZ_STOCK_FOLDER          "kz-folder"
+#define KZ_STOCK_FOLDER_OPEN     "kz-folder-open"
+#define KZ_STOCK_SEPARATOR       "kz-separator"
+#define KZ_STOCK_ANCHOR          "kz-anchor"
+#define KZ_STOCK_BOOKMARK        "kz-bookmark"
+#define KZ_STOCK_REMOTE_BOOKMARK "kz-remote-bookmark"
+#define KZ_STOCK_SCRAP_BOOKMARK  "kz-scrap-bookmark"
+#define KZ_STOCK_EDITOR          "kz-editor"
 
 extern GtkIconSize KZ_ICON_SIZE_BOOKMARK_MENU;
 
