@@ -702,7 +702,7 @@ kz_profile_get_value (KzProfile *profile,
 gboolean
 kz_profile_set_value (KzProfile *profile,
 		      const gchar *section,const gchar *key,
-		      gconstpointer value,const gint size,const guint type)
+		      gconstpointer value,const size_t size,const guint type)
 {
 	gchar *old_value = NULL;
 	gint i;
@@ -837,10 +837,17 @@ kz_profile_set_value (KzProfile *profile,
 
 
 static void
-kz_profile_list_free (KzProfileList *p)
+kz_profile_list_free (KzProfile *profile, KzProfileList *p)
 {
 	if (!p) return;
 
+	if (p == profile->list)
+		profile->list = p->next;
+	if (p->prev)
+		p->prev->next = p->next;
+	if (p->next)
+		p->next->prev = p->prev;
+
 	g_free(p->data);
 	g_free(p->section);
 	g_free(p->key);
@@ -877,18 +884,9 @@ kz_profile_delete_section (KzProfile *profile, const gchar *section)
 		q = p->next;
 		if (p->section && g_strcmp(p->section, section_tmp) == 0)
 		{
-			KzProfileList *prev = p->prev, *next = p->next;
-			if (prev && prev->type == KZ_PROFILE_DATA_TYPE_SPACE)
-			{
-				KzProfileList *tmp = prev->prev;
-				kz_profile_list_free(prev);
-				prev = tmp;
-			}
-			if (prev)
-				prev->next = next;
-			if (next)
-				next->prev = prev;
-			kz_profile_list_free(p);
+			if (p->prev && p->prev->type == KZ_PROFILE_DATA_TYPE_SPACE)
+				kz_profile_list_free(profile, p->prev);
+			kz_profile_list_free(profile, p);
 			profile->edit = TRUE;
 			result = TRUE;
 		}
@@ -939,11 +937,7 @@ gboolean kz_profile_delete_key (KzProfile *profile,
 		    && g_strcmp(p->section, section_tmp) == 0
 		    && g_strcmp(p->key, key_tmp) == 0)
 		{
-			if (p->prev)
-				p->prev->next = p->next;
-			if (p->next)
-				p->next->prev = p->prev;
-			kz_profile_list_free(p);
+			kz_profile_list_free(profile, p);
 			profile->edit = TRUE;
 			result = TRUE;
 		}
@@ -998,6 +992,18 @@ kz_profile_enum_section (KzProfile *profile)
 }
 
 
+static gint
+compare_enum_key (gconstpointer a, gconstpointer b)
+{
+	const gchar *one = (const gchar *)a;
+	const gchar *two = (const gchar *)b;
+	
+	if (strlen(one) != strlen(two))
+		return strlen(one) - strlen(two);
+	return strcmp(one, two);
+}
+
+
 /*
  * Enumelate keys in the initialize file.
  * profile,the KzProfile struct
@@ -1017,10 +1023,10 @@ kz_profile_enum_key (KzProfile *profile, const gchar *section)
 		if (p->section && p->key
 		    && g_strcmp(p->section, section) == 0
 		    && (!glist || !g_list_find_custom(glist, p->key,
-						     (GCompareFunc)strcmp)))
+						     (GCompareFunc)compare_enum_key)))
 		{
 			glist = g_list_insert_sorted(glist, p->key,
-						     (GCompareFunc)strcmp);
+						     (GCompareFunc)compare_enum_key);
 		}
 	}
 	for (p = profile->sublist; p; p = p->next)
@@ -1028,10 +1034,10 @@ kz_profile_enum_key (KzProfile *profile, const gchar *section)
 		if (p->section && p->key
 		    && g_strcmp (p->section, section) == 0
 		    && (!glist || !g_list_find_custom(glist, p->key,
-						      (GCompareFunc)strcmp)))
+						      (GCompareFunc)compare_enum_key)))
 		{
 			glist = g_list_insert_sorted(glist, p->key,
-						     (GCompareFunc)strcmp);
+						     (GCompareFunc)compare_enum_key);
 		}
 	}
 	return glist;
