@@ -91,12 +91,12 @@ struct KzProfileClass_Tag
 	/* -- signals -- */
 	void (*section_added)   (KzProfile *profile,
 				 const gchar *section);
-	void (*section_removed) (KzProfile *profile,
+	void (*section_deleted) (KzProfile *profile,
 				 const gchar *section);
 	void (*key_added)       (KzProfile *profile,
 				 const gchar *section,
 				 const gchar *key);
-	void (*key_removed)     (KzProfile *profile,
+	void (*key_deleted)     (KzProfile *profile,
 				 const gchar *section,
 				 const gchar *key);
 	void (*changed)         (KzProfile *profile,
@@ -192,7 +192,7 @@ gboolean kz_profile_set_value (KzProfile *profile,
 			       const gchar *section,
 			       const gchar *key,
 			       gconstpointer value,
-			       const gint size,
+			       const size_t size,
 			       const guint type);
 
 
