@@ -30,7 +30,7 @@
 #include "kz-actions-tab.h"
 #include "kz-icons.h"
 #include "kz-favicon.h"
-#include "eel-input-event-box.h"
+#include "kz-input-event-box.h"
 
 #define PROGRESSBAR_HEIGHT 16
 
@@ -46,7 +46,6 @@ struct _KzTabLabelPriv
 {
 	gint width;
 	gint start_x, start_y;
-	gboolean show_progress;
 	gboolean moved;
 	gboolean lock;
 	gulong favicon_signal;
@@ -216,8 +215,7 @@ kz_tab_label_init (KzTabLabel *kztab)
 	kztab->kzembed      = NULL;
 	kztab->state        = KZ_TAB_LABEL_STATE_NORMAL;
 	kztab->favicon      = gtk_image_new();
-	kztab->eventbox     = eel_input_event_box_new();
-	kztab->progressbar  = gtk_progress_bar_new();
+	kztab->eventbox     = kz_input_event_box_new();
 	kztab->label        = gtk_label_new(NULL);
 	kztab->close_button = gtk_button_new();
 	kztab->lock_button  = gtk_image_new_from_stock(KZ_STOCK_ANCHOR,
@@ -231,7 +229,6 @@ kz_tab_label_init (KzTabLabel *kztab)
 	kztab->priv->start_x           = 0;
 	kztab->priv->start_y           = 0;
 	kztab->priv->moved             = FALSE;
-	kztab->priv->show_progress     = FALSE;
 	kztab->priv->lock              = FALSE;
 	kztab->priv->favicon_signal    = 0;
 	
@@ -255,9 +252,6 @@ kz_tab_label_init (KzTabLabel *kztab)
 	gtk_widget_set_size_request(kztab->label, -1, -1);
 	gtk_widget_show (kztab->label);
 
-	/* progress bar */
-	gtk_widget_set_size_request(kztab->progressbar, -1, PROGRESSBAR_HEIGHT);
-
 	/* favicon */
 	gtk_icon_size_lookup(GTK_ICON_SIZE_MENU, &width, &height);
 	gtk_widget_set_size_request(kztab->favicon, width, height);
@@ -292,8 +286,6 @@ kz_tab_label_init (KzTabLabel *kztab)
 			   FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(hbox), kztab->label,
 			   TRUE, TRUE, 0);
-	gtk_box_pack_start(GTK_BOX(hbox), kztab->progressbar,
-			   TRUE, TRUE, 0);
 	/* 
 	 * close button (and other widget want to accept event signals)
 	 * must be outside the eel-input-event-box
@@ -510,7 +502,6 @@ kz_tab_label_set_text(KzTabLabel *kztab, const gchar *text)
 	if (!text || !*text) text = _("No title");
 
 	gtk_label_set_text(GTK_LABEL(kztab->label), text);
-	gtk_progress_bar_set_text(GTK_PROGRESS_BAR(kztab->progressbar), text);
 	gtk_tooltips_set_tip(kztab->tooltips, GTK_WIDGET(kztab->eventbox),
 			     text, NULL);
 }
@@ -528,26 +519,13 @@ kz_tab_label_set_state (KzTabLabel *kztab,
 	case KZ_TAB_LABEL_STATE_LOADING:
 		gtk_widget_modify_style(GTK_WIDGET(kztab->label),
 					kztab->style[KZ_TAB_LABEL_STATE_LOADING]);
-		gtk_widget_modify_style(GTK_WIDGET(kztab->progressbar),
-					kztab->style[KZ_TAB_LABEL_STATE_LOADING]);
-		if (kztab->priv->show_progress)
-		{
-			gtk_widget_show(kztab->progressbar);
-			gtk_widget_hide(kztab->label);
-			gtk_widget_set_size_request(kztab->progressbar,
-						    -1, PROGRESSBAR_HEIGHT);
-			gtk_widget_queue_resize(kztab->progressbar);
-		}
 		kztab->state = state;
 		break;
 
 	case KZ_TAB_LABEL_STATE_LOADED:
 		gtk_widget_modify_style(GTK_WIDGET(kztab->label),
 					kztab->style[KZ_TAB_LABEL_STATE_LOADED]);
-		gtk_widget_modify_style(GTK_WIDGET(kztab->progressbar),
-					kztab->style[KZ_TAB_LABEL_STATE_LOADED]);
 		gtk_widget_show(kztab->label);
-		gtk_widget_hide(kztab->progressbar);
 		gtk_widget_set_size_request(kztab->label, -1, -1);
 		gtk_widget_queue_resize(kztab->label);
 		kztab->state = state;
@@ -557,10 +535,7 @@ kz_tab_label_set_state (KzTabLabel *kztab,
 	default:
 		gtk_widget_modify_style(GTK_WIDGET(kztab->label),
 					kztab->style[KZ_TAB_LABEL_STATE_NORMAL]);
-		gtk_widget_modify_style(GTK_WIDGET(kztab->progressbar),
-					kztab->style[KZ_TAB_LABEL_STATE_NORMAL]);
 		gtk_widget_show(kztab->label);
-		gtk_widget_hide(kztab->progressbar);
 		gtk_widget_set_size_request(kztab->label, -1, -1);
 		gtk_widget_queue_resize(kztab->label);
 		kztab->state = KZ_TAB_LABEL_STATE_NORMAL;
@@ -584,10 +559,8 @@ kz_tab_label_set_width (KzTabLabel *kztab, gint width)
 	if (width < 0)
 	{
 		gtk_widget_set_size_request(kztab->label, -1, -1);
-		gtk_widget_set_size_request(kztab->progressbar, -1, -1);
 		gtk_widget_queue_resize(GTK_WIDGET(kztab));
 		gtk_widget_queue_resize(kztab->label);
-		gtk_widget_queue_resize(kztab->progressbar);
 	}
 	kztab->priv->width = width;
 }
@@ -616,29 +589,6 @@ kz_tab_label_set_show_lock_button (KzTabLabel *kztab, gboolean show)
 }
 
 
-void
-kz_tab_label_set_show_progress (KzTabLabel *kztab, gboolean show)
-{
-	g_return_if_fail(KZ_IS_TAB_LABEL(kztab));
-
-	if (kz_moz_embed_is_loading(kztab->kzembed))
-	{
-		if (show)
-		{
-			gtk_widget_hide(kztab->label);
-			gtk_widget_show(kztab->progressbar);
-		}
-		else
-		{
-			gtk_widget_show(kztab->label);
-			gtk_widget_hide(kztab->progressbar);
-		}
-	}
-
-	kztab->priv->show_progress = show;
-}
-
-
 void
 kz_tab_label_set_show_favicon (KzTabLabel *kztab, gboolean show)
 {
@@ -963,13 +913,9 @@ kz_tab_label_drag_data_received (GtkWidget *widget,
 	case TARGET_TEXT_PLAIN:
 	case TARGET_STRING:
 	{
-		gchar *string, **strings;
+		gchar **strings;
 
 		if (data->length < 0) return;
-		string = g_alloca (data->length + 1);
-
-		memcpy (string, data->data, data->length);
-		string[data->length] = '\0';
 
 		strings = g_strsplit(data->data, "\n", 2);
 		kz_moz_embed_load_url(kztab->kzembed,
@@ -989,7 +935,6 @@ kz_tab_label_sync_to_profile (KzTabLabel *kztab)
 	gint width = 80;
 	gboolean fix = TRUE;
 	gboolean show_close = TRUE;
-	gboolean show_progress = FALSE;
 	gboolean show_favicon = TRUE;
 
 	/* width */
@@ -1008,10 +953,6 @@ kz_tab_label_sync_to_profile (KzTabLabel *kztab)
 	/* lock button */
 	kz_tab_label_set_show_lock_button(kztab, kztab->priv->lock);
 
-	/* progress bar */
-	KZ_CONF_GET("Tab", "show_progress", show_progress, BOOL);
-	kz_tab_label_set_show_progress(kztab, show_progress);
-
 	/* favicon */
 	KZ_CONF_GET("Tab", "show_favicon", show_favicon, BOOL);
 	kz_tab_label_set_show_favicon(kztab, show_favicon);
@@ -1227,14 +1168,13 @@ cb_net_state_all (GtkMozEmbed *embed, const char *aURI,
 {
 	gdouble progress;
 	GtkWidget *widget;	       
+	GdkGC *gc;
 
 	g_return_if_fail(KZ_IS_TAB_LABEL(kztab));
 
 	widget = GTK_WIDGET(kztab);
 	progress = kz_moz_embed_get_progress(KZ_MOZ_EMBED(embed));
 
-	gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR(kztab->progressbar),
-				       progress);
 	if(GTK_WIDGET_REALIZED(widget))
 	{
 		GdkBitmap *mask;
@@ -1243,7 +1183,7 @@ cb_net_state_all (GtkMozEmbed *embed, const char *aURI,
 
 		mask = gdk_pixmap_new(widget->window,
 				      width, height, 1);
-		GdkGC *gc = gdk_gc_new(mask);
+		gc = gdk_gc_new(mask);
 		gdk_draw_rectangle(mask,
 				   gc,
 				   TRUE,
