@@ -182,7 +182,7 @@ static void     cb_notebook_switch_page       (GtkNotebook     *notebook,
 					       KzWindow        *kz);
 static void     cb_find_keyword               (GtkWidget       *widget,
 					       KzWindow        *kz);
-static gboolean cb_find_key_press             (GtkWidget       *widget,
+static gboolean cb_find_key_release           (GtkWidget       *widget,
 					       GdkEventKey     *event,
 					       KzWindow        *kz);
 static void     cb_find_direction_toggle      (GtkToggleButton *button,
@@ -576,8 +576,8 @@ kz_window_init (KzWindow *kz)
 		gtk_box_pack_start(GTK_BOX(kz->statusbar_area), kz->find_area,
 				   FALSE, FALSE, 0); 
 		g_signal_connect(G_OBJECT(GTK_ENTRY(kz->find_area)), 
-				 "key-press-event",
-				 G_CALLBACK(cb_find_key_press), kz);
+				 "key-release-event",
+				 G_CALLBACK(cb_find_key_release), kz);
 		gtk_widget_show(kz->find_area);
 
 		g_object_ref(G_OBJECT(tips));
@@ -1990,7 +1990,7 @@ cb_find_keyword (GtkWidget *widget, KzWindow *kz)
 
 
 static gboolean
-cb_find_key_press (GtkWidget *widget, GdkEventKey *event, KzWindow *kz)
+cb_find_key_release (GtkWidget *widget, GdkEventKey *event, KzWindow *kz)
 {
 	KzMozEmbed *embed ;
 	GtkToggleButton *toggle;
@@ -2012,6 +2012,13 @@ cb_find_key_press (GtkWidget *widget, GdkEventKey *event, KzWindow *kz)
 				= kz_moz_embed_find(embed, text, back);
 		}
 	}
+	else
+	{
+		gboolean back;
+		back = gtk_toggle_button_get_active(toggle);
+		kz->priv->did_find
+			= kz_moz_embed_incremental_search(embed, text, back);
+	}
 
 	return FALSE;
 }
