@@ -99,9 +99,8 @@ GtkWidget        *kz_window_new                      (const gchar *url);
 GtkWidget        *kz_window_get_from_tab             (GtkWidget   *tab_widget);
 GtkWidget        *kz_window_open_new_tab             (KzWindow    *kz,
 						      const gchar *url);
-GtkWidget        *kz_window_open_new_tab_at_position (KzWindow    *kz,
-						      const gchar *url,
-						      gint pos);
+GtkWidget        *kz_window_open_new_tab_at_tail     (KzWindow    *kz,
+						      const gchar *url);
 GtkWidget        *kz_window_open_new_tab_with_parent (KzWindow    *kz,
 						      const gchar *url,
 						      GtkWidget   *parent);
@@ -115,7 +114,6 @@ void              kz_window_move_tab                 (KzWindow    *kz,
 						      GtkWidget   *widget);
 void              kz_window_load_url                 (KzWindow    *kz,
 						      const gchar *url);
-void              kz_window_load_home                (KzWindow    *kz);
 void              kz_window_store_state              (KzWindow    *kz);
 void              kz_window_restore_state            (KzWindow    *kz);
 const gchar      *kz_window_get_title                (KzWindow    *kz);
