@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-xml.c,v 1.15 2003/12/06 10:23:24 ikezoe Exp $
+ *  $Id: kz-xml.c,v 1.19 2004/04/13 01:27:48 ikezoe Exp $
  */
 
 #include "kz-xml.h"
@@ -251,10 +251,10 @@ kz_xml_load_xml (KzXML *xml, const gchar *buffer, guint length)
 	GMarkupParseContext *context;
 	ParseContext *ctx;
 	gboolean ret = FALSE;
-	/* GError *error = NULL; */
+	GError *error = NULL; 
 
 	g_return_val_if_fail(KZ_IS_XML(xml), FALSE);
-	g_return_val_if_fail(buffer != NULL, FALSE);
+	if (buffer == NULL) return FALSE;
 
 	context = xml->priv->context;
 	if (!context)
@@ -271,12 +271,15 @@ kz_xml_load_xml (KzXML *xml, const gchar *buffer, guint length)
 		xml->priv->context = context;
 	}
 
-	if (g_markup_parse_context_parse(context, buffer, length, NULL))
+	if (g_markup_parse_context_parse(context, buffer, length, &error))
 	{
 		if (g_markup_parse_context_end_parse(context, NULL))
 			ret = TRUE;
 	}
-
+	else
+	{
+		g_warning("Bookmark parse error!: %s", error->message);
+	}
 	g_markup_parse_context_free (context);
 	xml->priv->context = NULL;
 
@@ -288,7 +291,7 @@ gboolean
 kz_xml_load (KzXML *xml, const gchar *filename)
 {
 	gchar *buffer = NULL;
-	gint length;
+	gsize length;
 	gboolean ret;
 	GError *error = NULL;
 
@@ -490,6 +493,7 @@ kz_xml_node_append_xml_string (KzXMLNode *node, GString *gstr)
 	else if (node->type == KZ_XML_NODE_TEXT)
 	{
 		gchar *escaped;
+//		escaped = g_strdup(node->content);
 
 		escaped = g_markup_escape_text(node->content, -1);
 		if (escaped)
@@ -904,7 +908,18 @@ kz_xml_node_is_space (KzXMLNode *node)
 	g_return_val_if_fail(node->content, FALSE);
 
 	str = node->content;
-
+	/*
+	 * "" is not space.
+	 * '<title></title>' won't make indent. 
+	 * Now, '<title></title>' does not make indent.
+	 * Formerly, 
+	 * <title></title>
+	 * is converted to 
+	 * <title>
+	 * </title>
+	 */
+	if (strlen(str) == 0)
+		return FALSE;
 	for (c = *str; *str; str++)
 	{
 		if (!isspace(*str))
