@@ -114,7 +114,6 @@ destroy_node (GNode *node, gpointer data)
 {
 	EggMenuMergeNode *mnode = NODE_INFO(node);
 
-#warning FIXME
 	g_free((gchar *) mnode->name);
 	mnode->name = NULL;
 
@@ -123,12 +122,13 @@ destroy_node (GNode *node, gpointer data)
 	if (mnode->action)
 		g_object_unref(mnode->action);
 	mnode->action = NULL;
-	g_free(mnode);
 
 	g_list_foreach(mnode->uifiles, (GFunc) g_free, NULL);
 	g_list_free(mnode->uifiles);
 	mnode->uifiles = NULL;
 
+	g_chunk_free(mnode, merge_node_chunk);
+
 	return FALSE;
 }
 
@@ -810,7 +810,7 @@ egg_menu_merge_add_ui_from_file (EggMenuMerge *self,
 				 GError **error)
 {
 	gchar *buffer;
-	gint length;
+	gsize length;
 	guint res;
 
 	if (!g_file_get_contents(filename, &buffer, &length, error))
@@ -1009,27 +1009,12 @@ update_node (EggMenuMerge *self, GNode *node)
 	EggMenuMergeNode *info;
 	GNode *child;
 	EggAction *action;
-	GList *tmp;
 
 	g_return_if_fail (node != NULL);
 	g_return_if_fail (NODE_INFO(node) != NULL);
 
 	info = NODE_INFO(node);
 
-	/*
-	g_print("update_node name=%s dirty=%d (", info->name, info->dirty);
-	for (tmp = info->uifiles; tmp != NULL; tmp = tmp->next)
-	{
-		NodeUIReference *ref = tmp->data;
-		g_print("%s:%u",
-			g_quark_to_string(ref->action_quark),
-			ref->merge_id);
-		if (tmp->next)
-			g_print(", ");
-	}
-	g_print(")\n");
-	*/
-
 	if (NODE_INFO(node)->dirty)
 	{
 		const gchar *action_name;
@@ -1108,25 +1093,32 @@ update_node (EggMenuMerge *self, GNode *node)
 			{
 				GtkWidget *menushell;
 				gint pos;
+				GNode *parent;
 
-				if (find_menu_position(node, &menushell, &pos))
+				parent = node->parent;
+
+				if (parent && NODE_INFO (parent)->type == EGG_MENU_MERGE_POPUPS)
+				{
+					info->proxy = gtk_menu_new();
+				}
+				else if (find_menu_position(node, &menushell, &pos))
 				{
 					GtkWidget *menu;
-					info->proxy = egg_action_create_menu_item(info->action);
+					info->proxy = egg_action_create_menu_item (info->action);
 					menu = gtk_menu_new();
 					gtk_menu_item_set_submenu(GTK_MENU_ITEM(info->proxy), menu);
-					gtk_menu_set_accel_group (GTK_MENU(menu), self->accel_group);
-					gtk_menu_shell_insert (GTK_MENU_SHELL(menushell),
+					gtk_menu_set_accel_group (GTK_MENU (menu), self->accel_group);
+					gtk_menu_shell_insert (GTK_MENU_SHELL (menushell),
 							       info->proxy, pos);
 				}
 			}
 			else
 			{
-				egg_action_connect_proxy(info->action, info->proxy);
+				egg_action_connect_proxy (info->action, info->proxy);
 			}
 			if (prev_submenu)
 			{
-				gtk_menu_item_set_submenu(GTK_MENU_ITEM(info->proxy),
+				gtk_menu_item_set_submenu (GTK_MENU_ITEM (info->proxy),
 							   prev_submenu);
 				g_object_unref (prev_submenu);
 			}
