@@ -66,6 +66,10 @@ struct _KzMozEmbed
 struct _KzMozEmbedClass
 {
 	GtkMozEmbedClass parent_class;
+
+	/* signal */
+	void (*favicon)        (KzMozEmbed *kzembed, const gchar *uri);	
+	void (*destroy_embed)  (KzMozEmbed *kzembed);	
 };
 
 
@@ -74,7 +78,8 @@ GtkWidget   *kz_moz_embed_new                (const gchar  *url);
 
 void         kz_moz_embed_load_url           (KzMozEmbed   *kzembed,
 					      const gchar  *url);
-void         kz_moz_embed_view_source        (KzMozEmbed   *kzembed);
+void         kz_moz_embed_view_source        (KzMozEmbed   *kzembed,
+					      const gchar  *url);
 
 #define      kz_moz_embed_is_loading(embed) \
                  (KZ_IS_MOZ_EMBED(embed) ? KZ_MOZ_EMBED(embed)->is_loading : FALSE)
@@ -94,9 +99,14 @@ void         kz_moz_embed_copy_selection     (KzMozEmbed   *kzembed);
 void         kz_moz_embed_paste              (KzMozEmbed   *kzembed);
 void         kz_moz_embed_select_all         (KzMozEmbed   *kzembed);
 
+gchar       *kz_moz_embed_get_selection_string(KzMozEmbed   *kzembed);
+
 gboolean     kz_moz_embed_find               (KzMozEmbed   *embed,
 					      const char   *keyword,
 					      gboolean      backward);
+gboolean     kz_moz_embed_incremental_search (KzMozEmbed   *embed,
+					      const char   *keyword,
+					      gboolean      backward);
 
 gboolean     kz_moz_embed_selection_is_collapsed
 					     (KzMozEmbed   *kzembed);
@@ -120,23 +130,65 @@ glong        kz_moz_embed_get_mouse_event_info
 
 void         kz_moz_embed_copy_page          (KzMozEmbed   *kzembed,
 					      KzMozEmbed   *dkzembed);
-gboolean     kz_moz_embed_shistory_copy      (KzMozEmbed *source,
-					      KzMozEmbed *dest,
-					      gboolean back_history,
-					      gboolean forward_history,
-					      gboolean set_current);
+gboolean     kz_moz_embed_shistory_copy      (KzMozEmbed   *source,
+					      KzMozEmbed   *dest,
+					      gboolean      back_history,
+					      gboolean      forward_history,
+					      gboolean      set_current);
+gboolean     kz_moz_embed_shistory_get_pos   (KzMozEmbed *kzembed,
+					      int *pos, int *count);
+void         kz_moz_embed_shistory_get_nth   (KzMozEmbed *kzembed, 
+					      int nth,
+					      gboolean is_relative,
+					      char **aUrl,
+					      char **aTitle);
 
-gboolean     kz_moz_embed_can_go_first(KzMozEmbed *kzembed);
-gboolean     kz_moz_embed_can_go_last (KzMozEmbed *kzembed);
-gboolean     kz_moz_embed_can_go_prev (KzMozEmbed *kzembed);
-gboolean     kz_moz_embed_can_go_next (KzMozEmbed *kzembed);
+void         kz_moz_embed_reload             (KzMozEmbed   *kzembed,
+					      gint32 flags);
+void         kz_moz_embed_stop_load          (KzMozEmbed   *kzembed);
+void         kz_moz_embed_go_back            (KzMozEmbed   *kzembed);
+void         kz_moz_embed_go_forward         (KzMozEmbed   *kzembed);
+void         kz_moz_embed_go_up              (KzMozEmbed   *kzembed);
 
-void         kz_moz_embed_go_first (KzMozEmbed *kzembed);
-void         kz_moz_embed_go_last  (KzMozEmbed *kzembed);
-void         kz_moz_embed_go_next  (KzMozEmbed *kzembed);
-void         kz_moz_embed_go_prev  (KzMozEmbed *kzembed);
+gboolean     kz_moz_embed_can_go_back     (KzMozEmbed *kzembed);
+gboolean     kz_moz_embed_can_go_forward  (KzMozEmbed *kzembed);
+gboolean     kz_moz_embed_can_go_up       (KzMozEmbed *kzembed);
+gboolean     kz_moz_embed_can_go_index    (KzMozEmbed *kzembed);
+gboolean     kz_moz_embed_can_go_contents (KzMozEmbed *kzembed);
+gboolean     kz_moz_embed_can_go_start    (KzMozEmbed *kzembed);
+gboolean     kz_moz_embed_can_go_prev     (KzMozEmbed *kzembed);
+gboolean     kz_moz_embed_can_go_next     (KzMozEmbed *kzembed);
 
-gboolean impl_save (KzMozEmbed *embed);
+void         kz_moz_embed_go_index     (KzMozEmbed *kzembed);
+void         kz_moz_embed_go_contents  (KzMozEmbed *kzembed);
+void         kz_moz_embed_go_start     (KzMozEmbed *kzembed);
+void         kz_moz_embed_go_next      (KzMozEmbed *kzembed);
+void         kz_moz_embed_go_prev      (KzMozEmbed *kzembed);
+
+gboolean     kz_moz_embed_get_lock     (KzMozEmbed *kzembed);
+void         kz_moz_embed_set_lock     (KzMozEmbed *kzembed,
+					gboolean    lock);
+
+gchar       *kz_moz_embed_get_body_text       (KzMozEmbed *kzembed);
+gchar       *kz_moz_embed_get_selection_source(KzMozEmbed *kzembed);
+
+void         kz_moz_embed_set_encoding (KzMozEmbed *kzembed,
+					const char *encoding);
+void         kz_moz_embed_get_encoding (KzMozEmbed *kzembed,
+					char **encoding,
+					gboolean *forced);
+void         kz_moz_embed_print        (KzMozEmbed *kzembed);
+void         kz_moz_embed_print_preview(KzMozEmbed *kzembed);
+
+
+gboolean     kz_moz_embed_save_with_content (KzMozEmbed *kzembed,
+					     const char *rawfilename);
+
+gboolean     kz_moz_embed_set_text_into_textarea (KzMozEmbed *kzembed,
+						  gpointer element,
+						  const gchar *text);
+gchar       *kz_moz_embed_get_text_from_textarea (KzMozEmbed *kzembed,
+						  gpointer element);
 
 G_END_DECLS
 
