@@ -66,8 +66,12 @@
 #include <htmlparser/nsIParser.h>
 #include <chardet/nsIDocumentCharsetInfo.h>
 #include <nsIOutputStream.h>
+#include <nsReadableUtils.h>
+#include <necko/nsNetUtil.h>
+#include <nsIWebBrowserPrint.h>
 
 #include "nsUnicharUtils.h"
+#include "kz-mozprogresslistener.h"
 #include "utils.h"
 
 #ifdef HAVE_CONFIG_H
@@ -76,8 +80,6 @@
 
 #define SCRAP_IMAGE_DIR "scrap_images/"
 
-static NS_DEFINE_CID(kFileTransportServiceCID, NS_FILETRANSPORTSERVICE_CID);
-
 KzMozWrapper::KzMozWrapper () :
 	mWebBrowser (nsnull),
 	mEventReceiver (nsnull),
@@ -1017,24 +1019,60 @@ KzMozWrapper::MoveImageToLocal (const nsACString &URI, nsAString &LocalFile)
 		LocalFile.Assign(NS_ConvertUTF8toUCS2(SCRAP_IMAGE_DIR));
 		LocalFile.Append(NS_ConvertUTF8toUCS2(filename));
 
-		nsAutoString newFileName;
-		newFileName.Assign(NS_ConvertUTF8toUCS2(filename));
-
-		gsize byte_written;
 		make_dir(SCRAP_IMAGE_DIR);
-		GIOChannel *io = g_io_channel_new_file(dir, "w", NULL);
-		if (io)
-		{
-			g_io_channel_set_encoding(io, NULL, NULL);
-			g_io_channel_write_chars(io, 
-						 buf,
-						 dataSize,
-						 &byte_written,
-						 NULL);
-			g_io_channel_unref(io);
-		}
+		
+		nsCOMPtr<nsILocalFile> imageFile = do_CreateInstance(NS_LOCAL_FILE_CONTRACTID);
+		imageFile->InitWithPath(NS_ConvertUTF8toUCS2(dir));
+		imageFile->Create(nsIFile::NORMAL_FILE_TYPE, 0600);
+		nsCOMPtr<nsIOutputStream> outStream;
+		NS_NewLocalFileOutputStream(getter_AddRefs(outStream),
+					    imageFile,
+					    -1,
+					    0600);
+		outStream->Write(buf, dataSize, &rv);
+		outStream->Close();
+
 		g_free(filename);
 		g_free(dir);
 		g_free(buf);
 	}
 }
+
+
+nsresult
+KzMozWrapper::Print (void)
+{
+	nsresult result;
+        nsCOMPtr<nsIPrintSettings> options;
+
+	g_return_val_if_fail (mWebBrowser, NS_ERROR_FAILURE);
+
+	nsCOMPtr<nsIWebBrowserPrint> print(do_GetInterface(mWebBrowser, &result));
+	if (NS_FAILED(result) || !print) return NS_ERROR_FAILURE;
+
+	print->GetGlobalPrintSettings(getter_AddRefs(options));
+	options->SetPaperSize(nsIPrintSettings::kPaperSizeNativeData);
+	
+	KzMozProgressListener *aProgress = new KzMozProgressListener();
+	result = print->Print(options, aProgress);
+
+	return result;
+}
+
+nsresult
+KzMozWrapper::PrintPreview (void)
+{
+	nsresult result;
+        nsCOMPtr<nsIPrintSettings> options;
+
+	g_return_val_if_fail (mWebBrowser, NS_ERROR_FAILURE);
+
+	nsCOMPtr<nsIWebBrowserPrint> print(do_GetInterface(mWebBrowser, &result));
+	if (NS_FAILED(result) || !print) return NS_ERROR_FAILURE;
+
+	print->GetGlobalPrintSettings(getter_AddRefs(options));
+	options->SetPaperSize(nsIPrintSettings::kPaperSizeNativeData);
+	result = print->PrintPreview(options, mDOMWindow, nsnull);
+
+	return result;
+}
