@@ -92,6 +92,7 @@ mozilla_prefs_set (void)
 	gboolean override = FALSE, typeahead = FALSE;
 	gchar proxy_name[1024];
 	gboolean conf_exist = FALSE;
+	KzProxyItem *item = NULL;
 
 	// set user agent name
 	KZ_CONF_GET("Global", "override_user_agent", override, BOOL);
@@ -118,8 +119,9 @@ mozilla_prefs_set (void)
 
 	conf_exist = KZ_CONF_GET("Global", "proxy_name", proxy_name, STRING);
 	if (conf_exist)
+		item = kz_proxy_find(proxy_name);
+	if (item)
 	{
-		KzProxyItem *item = kz_proxy_find(proxy_name);
 		mozilla_prefs_set_proxy(item);
 		g_object_unref(G_OBJECT(item));
 	}
@@ -391,8 +393,8 @@ mozilla_prefs_set_proxy (KzProxyItem *item)
 			ftp_port = 0;
 		}
 	}
-	mozilla_prefs_set_string("network.proxy.https",      https_host);
-	mozilla_prefs_set_int   ("network.proxy.https_port", https_port);
+	mozilla_prefs_set_string("network.proxy.ssl",      https_host);
+	mozilla_prefs_set_int   ("network.proxy.ssl_port", https_port);
 	mozilla_prefs_set_string("network.proxy.ftp",        ftp_host);
 	mozilla_prefs_set_int   ("network.proxy.ftp_port",   ftp_port);
 }
